c
c Stand-alone Microwave RTA
c
c this reads the RTP file specified by fin
c and writes  an RTP file specified by fout
c
c  P. Rosenkranz, June 27, 2001 for RTP vers. 0.99
C 14 September 2001, Scott Hannon - change some variables
C    and routine names upper/lower case to match declarations.
c 
        program m_rta
        implicit none
c
c RTP declarations
c
        include 'rtpdefs.f'
        integer rtpopen, rtpread, rtpwrite, rtpclose
        record /RTPHEAD/ head
        record /RTPPROF/ prof
        record /RTPATTR/ hatt(MAXNATTR), patt(MAXNATTR)
c 
c other variables
c
        integer i, j
        integer status
        integer chan1, chan2
        character*64 fin, fout, mode
C
c declarations for the MW calculation
c
        integer NMWEM
        parameter (NMWEM=7)
        real h2om, ratio, grav
        parameter (h2om=2.991e-23, ratio=.6221e-6, grav=.980665)
        logical levelpro
        integer nlayer, ior, iprt, iounit, iret, k, ii
        real p(MAXLEV), t(MAXLEV), tran(MAXLEV), tranr(MAXLEV)
        real h2ovcd(MAXLEV), h2olcd(MAXLEV), mmr, secant, eps,epsv,epsh
        real h2ovmr(MAXLEV),ti(MAXLEV),tsurf,wind,fracland,fv,emisocean
        real secratio(MWMAXCHAN) ! assumed ratio of reflected to direct 
c                                path length
        real td !atmospheric emission from direct path
        real tr !atmospheric emission from reflected path
        real e !total atmospheric transmittance on direct path 
        real er !total atmospheric transmittance on reflected path 
        real freqs(NMWEM)  ! frequencies for surface emissivity
        real emismw(NMWEM) ! microwave emissivities at nominal freqs.
        real tcb(NMWEM) ! equiv. cosmic background temps at nominal freqs,
c                    to linearize Planck's function
        integer emch(MWMAXCHAN)   ! index into emismw list from MW
c                                 channel num.
        real freq(MWMAXCHAN)      ! channel center freq (GHz)
        character*64 tramsua,trhsb
c 
        DATA freqs/23.8, 31.4, 50.3, 52.8, 89., 150., 183.3/
        DATA tcb/2.73, 2.73, 2.91, 2.91, 3.27, 4.16, 4.77/
        data emch/1, 2, 3, 11*4, 2*5, 6, 3*7/
        data secratio / 3*1.15, 11*1.10, 6*1.15 /
        namelist /m_rta_fn/ tramsua,trhsb,fin,fout,iprt
        iounit = 1
c
c zero out liquid water
        do k=1,MAXLEV
          h2olcd(k) = 0.
        end do
c
c get filenames
        open(iounit,file='m_rta.nl',status='old',form='formatted')
        read(iounit,m_rta_fn)
        close(iounit)
c
c read MW transmittance coefficients
c
        open(iounit,file=tramsua,status='old',form='formatted')
        call GETCOEF(iounit, iret, freq )
        print *, 'AMSU coeff file status =', iret
        close(iounit)
        open(iounit,file=trhsb,status='old',form='formatted')
        call GETCOEF(iounit, iret, freq(16) )
        print *, 'HSB coeff file status =', iret
        close(iounit)
c
c open the input file for reading
c
        mode = 'r'
        status = rtpopen(fin, mode, head, hatt, patt, chan1)
        print *, 'read open status = ', status
        print *, 'ptype=', head.ptype
        print *, 'pfields=', head.pfields
        print *, 'num. IR chan =',head.nchan
        print *, 'H2O unit =',head.gunit(1)
        levelpro = head.ptype .eq. LEVPRO
c
c add an attribute
c
        i = 1
        do while (hatt(i).fname(1:1) .ne. char(0) .and. i .lt. MAXNATTR)
          print *, i, hatt(i).fname
          print *, i, hatt(i).aname
          print *, i, hatt(i).atext
          i = i + 1
        end do
        hatt(i).fname = 'header'//char(0)
        hatt(i).aname = 'm_rta'//char(0)
        hatt(i).atext = 'vers. 0.99 MW TB calc.'//char(0)
        hatt(i+1).fname = char(0)
c
c update the header data
c
        head.pfields = ior(head.pfields, MWCALCBIT)
        head.mwmemis = NMWEM
c Note: head.mwmemis is obsolete but still necessary, rtp 1.01 bug.
C       Assign channel frequencies; added by Scott H.
        do i = 1,MWMAXCHAN
           head.mwfchan(i)=freq(i)
        enddo
c
c create the output file
c
        mode = 'c'
        status = rtpopen(fout, mode, head, hatt, patt, chan2)
        print *, 'create open status = ', status
c
c loop on profiles, until EOF
c
        i = 0
10      continue !head of loop
          status = rtpread(chan1, prof)
          if (status .eq. -1) goto 22
          i = i + 1
c
c put profiles in vectors for use by mwtran - note that for
c mwtran, the first layer extends from the top of the atmosphere
c to the first pressure level.
c This assumes gunit(1)=10
c
        if(levelpro) then 
            nlayer = prof.nlevs
        else
            nlayer = prof.nlevs - 1
        endif
        if(prof.plevs(2) .lt. prof.plevs(1)) then ! reverse the order
           do j=1,nlayer
              k = prof.nlevs + 1 - j
              p(j) = prof.plevs(k)
              ii = nlayer + 1 - j
              ti(j) = prof.ptemp(ii)
              h2ovmr(j) = amax1(prof.gamnt(ii,1) , 0.)
           end do
        else
           do j=1,nlayer
              ti(j) = prof.ptemp(j)
              h2ovmr(j) = amax1(prof.gamnt(j,1) , 0.)
              if(levelpro) then
                p(j) = prof.plevs(j)
              else
                p(j) = prof.plevs(j+1)
              endif
           end do
        endif
c
        t(1) = ti(1)
        h2ovcd(1) = 0.
        do k=2,nlayer
         if(levelpro) then
           t(k) = (ti(k)+ti(k-1))/2.
            mmr = ratio*(h2ovmr(k)+h2ovmr(k-1))/2.
         else
            t(k) = ti(k)
            mmr = ratio*h2ovmr(k)
         endif
            h2ovcd(k) = mmr*(p(k)-p(k-1))/((1.+mmr)*h2om*grav)
        end do
c
        if(iprt.gt.0) then
          print *, 'num.levs & layers', prof.nlevs, nlayer, i
          do k=1,nlayer
            write(*,1) prof.plevs(k),p(k),prof.ptemp(k),t(k),
     &      prof.gamnt(k,1),h2ovcd(k)
1           format(1x,4f8.2,2e12.3)
          end do
        endif
c
c compute emissivities at the 7 nominal frequencies
c
      if(prof.stemp.gt.0.) then
         tsurf = prof.stemp
      else
         tsurf = ti(nlayer)
      endif
c
      wind = amax1( prof.wspeed, 0. )
      fracland = prof.landfrac
c
      if(tsurf.gt.273.2) then 
c  compute ocean-surface emissivities
       do j=1,NMWEM
        call FASTEM(freqs(j),prof.satzen,tsurf,wind,.035,
     &   epsv,epsh,1,1,1)
        fv = cos(prof.scanang/57.296)**2
        emisocean = fv*epsv + (1.-fv)*epsh
        emismw(j) = (1.-fracland)*emisocean + fracland
       end do
c
      else !use default values
          do j=1,NMWEM
            emismw(j) = 1.
          end do
          print *, i,' WARNING: using unity for MW emissivities'
      endif
c
        if(prof.mwnstb.eq.NMWEM .and. fracland.gt. 0.1) then !use 
c        observed surface brightness instead
          do j=1,NMWEM
           emismw(j) = amin1(prof.mwstb(j)/tsurf, 1.)
          end do
        endif
c
c store emissivities
        do j=1,NMWEM
          prof.mwemis(j) = emismw(j)
          prof.mwefreq(j) = freqs(j)
        end do
        prof.mwnemis = NMWEM
c
c add MW radiance data
c
        secant = 1./cos(prof.satzen/57.296)
        do j = 1, MWMAXCHAN
          call mwtran(secant,secratio(j),tran,tranr,nlayer,
     &       p,t,.false.,h2ovcd,h2olcd,prof.plat,prof.plon,j)
          call TB11(td,tr,e,er,nlayer,t,tran,tranr)
          eps = emismw(emch(j))
          prof.mwcalc(j) = td + e*( eps*tsurf +
     &     (1.-eps)*(tr+er*tcb(emch(j))) )
        end do
c
c
c write out the updated profile
c
          status = rtpwrite(chan2, prof)
          print *, 'write status = ', status, i

        goto 10

 22     continue

        status = rtpclose(chan1)
        print *, 'read close status = ', status

        status = rtpclose(chan2)
        print *, 'write close status = ', status

        stop
        end

