/*

NAME    

  rtpinit -- initialze RTP profile structures

SUMMARY

  rtpinit initializes RTP profile structures with some sensible
  default vaules, and is used when creating a profile; it should
  generally not be used when modifying an existing profile.

  rtpinit sets all field sizes to zero, and all data 
  values to "BAD", so that only actual values and sizes need to
  be written

  rtpwrite writes an RTP profile, represented as the contents
  of an RTPPROF structure, to an open RTP channel.  Successive
  calls write successive profiles.

FORTRAN PARAMETERS

  data type             name      short description       direction
  ---------             -----     -----------------       ---------
  STRUCTURE /RTPHEAD/   head      RTP header structure       OUT
  STRUCTURE /RTPPROF/   prof      RTP profile structure      OUT

VALUE RETURNED

  0 if successful, -1 on errors

*/

#include "rtp.h"
#include "rtpfnx.h"

int rtpwrite(
              struct rtp_head *head   /* RTP header structure  */
              struct rtp_prof *prof   /* RTP profile structure */
              ) {

  /* initial header values 
   */
  head->ptype           = LEVPRO;
  head->pfields         = PROFBIT;

  head->pmin            = BAD;
  head->pmax            = BAD;
  head->ngas            = 0;
  head->glist[0]        = BAD;
  head->gunit[0]        = BAD;

  head->nchan           = 0;
  head->ichan[0]        = BAD;
  head->vchan[0]        = BAD;

  head->mwnchan         = 0;
  head->mwfchan[0]      = BAD;

  head->mrho 		= 0;
  head->memis 		= 0;
  head->mlevs 		= 0;
  head->mwmemis 	= 0;
  head->mwmstb 		= 0;

  head->udef1           = BAD;
  head->udef2           = BAD;

  /* initial profile values 
   */
 
  prof->plat            = BAD;
  prof->plon            = BAD;
  prof->ptime           = BAD;

  prof->stemp           = BAD;
  prof->nrho            = 0;
  prof->rho[0]          = BAD;
  prof->rfreq[0]        = BAD;
  prof->nemis           = 0;
  prof->emis[0]         = BAD;
  prof->efreq[0]        = BAD;
  prof->salti           = BAD;
  prof->spres           = BAD;

  prof->nlevs           = 0;
  prof->plevs[0]        = BAD;
  prof->plays[0]        = BAD;
  prof->palts[0]        = BAD;
  prof->ptemp[0]        = BAD;
  prof->gamnt[0][0]     = BAD;
  prof->co2ppm          = BAD;

  prof->scanang         = BAD;
  prof->satzen          = BAD;
  prof->satazi          = BAD;
  prof->solzen          = BAD;
  prof->solazi          = BAD;

  prof->cfrac           = BAD;
  prof->cemis           = BAD;
  prof->cprtop          = BAD;
  prof->cprbot          = BAD;
  prof->cngwat          = BAD;
  prof->cpsize          = BAD;

  prof->landfrac        = BAD;
  prof->wspeed          = BAD;
  prof->wsource         = BAD;

  prof->mwnemis         = 0;
  prof->mwefreq[0]      = BAD;
  prof->mwemis[0]       = BAD;
  prof->mwnstb          = 0;
  prof->mwsfreq[0]      = BAD;
  prof->mwstb[0]        = BAD;

  prof->rcalc[0]        = BAD;
  prof->mwcalc[0]       = BAD;

  prof->rlat            = BAD;
  prof->rlon            = BAD;
  prof->rtime           = BAD;
  prof->robs1[0]        = BAD;
  prof->mwobs[0]        = BAD;

  prof->granule         = BAD;
  prof->scanline        = BAD;
  prof->footprint       = BAD;

  prof->udef1           = BAD;
  prof->udef2           = BAD;

  return (0);
}

